@@ -30,22 +30,31 @@ knit_print.tinytable <- function(x,
 print.tinytable <- function(x,
                             output = getOption("tinytable_print_output", default = NULL),
                             ...){
-  # lazy styles get evaluated here, at the very end
-  out <- build_tt(x, output = output)
 
-  if (meta(out, "output") == "latex") {
+  assert_choice(output, c("latex", "markdown", "html"), null.ok = TRUE)
+
+  if (is.null(output)) output <- meta(x, "output")
+
+  # lazy styles get evaluated here by build_tt(), at the very end
+  if (output == "latex") {
+    out <- build_tt(x, output = "latex")
     class(out) <- "character"
     cat("\n")
     cat(out)
     cat("\n")
 
-  } else if (meta(out, "output") == "markdown") {
+  } else if (output == "markdown") {
+    out <- build_tt(x, output = "markdown")
     cat("\n")
     cat(out, sep = "\n")
 
-  } else if (meta(out, "output") == "html") {
+  } else if (output == "html") {
+    # need to change the output directory to a temporary directory 
+    # for plot_tt() inline plots to show up in RStudio
     dir <- tempfile()
+    x <- meta(x, "output_dir", dir)
     dir.create(dir)
+    out <- build_tt(x, output = "html")
     htmlFile <- file.path(dir, "index.html")
     cat(out, file = htmlFile)
     if (isTRUE(check_dependency("rstudioapi")) && rstudioapi::isAvailable()) {
