@@ -11,10 +11,14 @@ style_tabularray <- function(x,
                              fontsize = NULL,
                              width = NULL,
                              align = NULL,
+                             line = NULL,
+                             line_color = "black",
+                             line_width = .1,
                              colspan = NULL,
                              indent = 0,
                              tabularray_inner = NULL,
-                             tabularray_outer = NULL) {
+                             tabularray_outer = NULL,
+                             ...) {
 
   if (meta(x, "output") != "latex") return(x)
 
@@ -77,7 +81,7 @@ style_tabularray <- function(x,
   settings$tabularray <- sprintf("%s, cmd=%s,", settings$tabularray, cmd)
 
   # hex must be treated differently in LaTeX
-  cols <- c(color, background)
+  cols <- c(color, background, line_color)
   cols_done <- NULL
   if (!is.null(cols)) {
     hex <- cols[grepl("^#", cols)]
@@ -102,15 +106,50 @@ style_tabularray <- function(x,
   settings$tabularray <- trimws(gsub("\\s+", "", settings$tabularray))
   settings$tabularray <- trimws(gsub(",+", ",", settings$tabularray))
 
-  for (k in seq_len(nrow(settings))) {
-    if (all(c("i", "j") %in% colnames(settings))) {
-      spec <- sprintf("cell{%s}{%s}={%s}{%s},", settings$i[k], settings$j[k], span, settings$tabularray[k])
-    } else if ("i" %in% colnames(settings)) {
-      spec <- sprintf("row{%s}={%s},", settings$i[k], settings$tabularray[k])
-    } else if ("j" %in% colnames(settings)) {
-      spec <- sprintf("column{%s}={%s},", settings$j[k], settings$tabularray[k])
-    } 
-    out <- tabularray_insert(out, content = spec, type = "inner")
+
+  if (!all(settings$tabularray == ",")) {
+    for (k in seq_len(nrow(settings))) {
+      if (all(c("i", "j") %in% colnames(settings))) {
+        spec <- sprintf("cell{%s}{%s}={%s}{%s},", settings$i[k], settings$j[k], span, settings$tabularray[k])
+      } else if ("i" %in% colnames(settings)) {
+        spec <- sprintf("row{%s}={%s},", settings$i[k], settings$tabularray[k])
+      } else if ("j" %in% colnames(settings)) {
+        spec <- sprintf("column{%s}={%s},", settings$j[k], settings$tabularray[k])
+      }
+      out <- tabularray_insert(out, content = spec, type = "inner")
+    }
+  }
+
+  # Lines are not part of cellspec/rowspec/columnspec. Do this separately.
+  if (!is.null(line)) {
+    iline <- jline <- NULL
+    if (grepl("t", line)) iline <- c(iline, ival + meta(x, "nhead"))
+    if (grepl("b", line)) iline <- c(iline, ival + meta(x, "nhead") + 1)
+    if (grepl("l", line)) jline <- c(jline, jval)
+    if (grepl("r", line)) jline <- c(jline, jval + 1)
+    iline <- unique(iline)
+    jline <- unique(jline)
+    line_width <- paste0(line_width, "em")
+    if (!is.null(iline)) {
+      tmp <- sprintf(
+        "hline{%s}={%s}{solid, %s, %s},",
+        paste(iline, collapse = ","),
+        paste(jval, collapse = ","),
+        line_width,
+        sub("^#", "c", line_color)
+      )
+      out <- tabularray_insert(out, content = tmp, type = "inner")
+    }
+    if (!is.null(jline)) {
+      tmp <- sprintf(
+        "vline{%s}={%s}{solid, %s, %s},",
+        paste(jline, collapse = ","),
+        paste(ival + meta(x, "nhead"), collapse = ","),
+        line_width,
+        sub("^#", "c", line_color)
+      )
+      out <- tabularray_insert(out, content = tmp, type = "inner")
+    }
   }
 
   out <- tabularray_insert(out, content = tabularray_inner, type = "inner")
