@@ -13,9 +13,7 @@
 #' @param digits Number of significant digits to keep for numeric variables. When `digits` is an integer, `tt()` calls `format_tt(x, digits = digits)` before proceeding to draw the table. Users who need more control can proceed in two steps: (1) format the data with `format_tt()` or other functions, and (2) pass the formatted data to `tt()` for drawing. See `?format_tt` for more details on formating options (ex: decimal, scientific notation, dates, boolean variables, etc.).
 #' @param caption A string that will be used as the caption of the table.
 #' @param width A numeric value between 0 and 1 indicating the proportion of the line width that the table should cover.
-#' @param theme The theme to apply to the table.
-#' * LaTeX: "default", "striped", "void", or "grid".
-#' * HTML: "default", "striped", "void", "grid", or a (composite) 
+#' @param theme The theme to apply to the table: "default", "striped", "bootstrap", "void", or "grid".
 #' @param notes A single string or a (named) list of strings to append at the bottom of the table.
 #' 
 #' @param placement A string to control the position of tables in LaTeX. Will be inserted in square brackets like: `\\begin{table}[H]`
@@ -49,6 +47,7 @@ tt <- function(x,
   assert_string(caption, null.ok = TRUE)
   assert_numeric(width, len = 1, lower = 0, upper = 1, null.ok = TRUE)
   assert_integerish(digits, len = 1, null.ok = TRUE)
+  assert_choice(theme, c("default", "grid", "void", "striped", "bootstrap"))
 
   
   # notes can be a single string or a (named) list of strings
@@ -60,15 +59,15 @@ tt <- function(x,
   # before style_tt() call for align
   out <- x 
   out <- meta(out, "x_character", data.frame(lapply(x, as.character)))
-  out <- meta(out, "output", output)
+  out <- meta(out, "output", sanitize_output(output))
   out <- meta(out, "output_dir", getwd())
   out <- meta(out, "colnames", names(x))
   out <- meta(out, "xdim", dim(x))
-  out <- meta(out, "output", output)
   out <- meta(out, "id", get_id("tinytable_"))
   out <- meta(out, "nhead", if (is.null(colnames(x))) 0 else 1)
   out <- meta(out, "nrows", nrow(x))
   out <- meta(out, "ncols", ncol(x))
+  out <- meta(out, "caption", caption)
   class(out) <- c("tinytable", class(out))
 
   # build table
